import "./tasks/hisat2.wdl" as hisat2
import "./tasks/samtools.wdl" as samtools
import "./tasks/stringtie.wdl" as stringtie
import "./tasks/ballgown.wdl" as ballgown

workflow {{ project_name }} {

	File read1
	File read2
    File idx
	String idx_prefix
    File gtf
	
	
	call hisat2.hisat2 as hisat2 {
		input: 
		docker = hisat2_docker,
		cluster = hisat2_cluster,
		idx=idx, 
		idx_prefix=idx_prefix, 
		read_1P=read1, 
		read_2P=read2
	}

    call samtools.samtools as samtools {
        input: 
		docker = samtools_docker,
		cluster = samtools_cluster,
		sam = hisat2.sam
	}

    call stringtie.stringtie as stringtie {
        input: 
		docker = stringtie_docker,
		cluster = stringtie_cluster,
		gtf = gtf, 
		bam = samtools.out_bam
	}   

	call ballgown.ballgown as ballgown {
		input: 
		docker = ballgown_docker,
		cluster = ballgown_cluster,
		ballgown = stringtie.ballgown
	} 
	
}


